@@ -1,5 +1,7 @@
 var NAVTREEINDEX105 =
 {
+"structinternal_1_1OptionalDownloadProgressReport.html#ab8bd72ec50dd64827b3d3892595bc118":[3,0,2,2,0],
+"structinternal_1_1OptionalDownloadProgressReport.html#ab8bd72ec50dd64827b3d3892595bc118":[4,0,1,2,0],
 "structinternal_1_1OptionalDownloadProgressReport.html#ab8e29ffe6d37397ea93eeffff724c331":[3,0,2,2,16],
 "structinternal_1_1OptionalDownloadProgressReport.html#ab8e29ffe6d37397ea93eeffff724c331":[4,0,1,2,16],
 "structinternal_1_1OptionalDownloadProgressReport.html#acb39d4cd8b92bb52bedb40811bc35b5a":[3,0,2,2,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX105 =
 "structztui_1_1TermLine.html#a8831edaddeb682b3f86aebabaad331a2":[3,0,9,22,13],
 "structztui_1_1TermLine.html#a8831edaddeb682b3f86aebabaad331a2":[4,0,6,19,13],
 "structztui_1_1TermLine.html#aa1672fc18fe4b72fa1f62dacbd1744f7":[3,0,9,22,6],
-"structztui_1_1TermLine.html#aa1672fc18fe4b72fa1f62dacbd1744f7":[4,0,6,19,6],
-"structztui_1_1TermLine.html#ab7130f9732fa9695f7232396cb57f0f5":[3,0,9,22,15],
-"structztui_1_1TermLine.html#ab7130f9732fa9695f7232396cb57f0f5":[4,0,6,19,15]
+"structztui_1_1TermLine.html#aa1672fc18fe4b72fa1f62dacbd1744f7":[4,0,6,19,6]
 };
