@@ -1,5 +1,7 @@
 var NAVTREEINDEX106 =
 {
+"structztui_1_1TermLine.html#ab7130f9732fa9695f7232396cb57f0f5":[3,0,9,22,15],
+"structztui_1_1TermLine.html#ab7130f9732fa9695f7232396cb57f0f5":[4,0,6,19,15],
 "structztui_1_1TermLine.html#ab9630078346cb7d8426c2e77a71a62c8":[3,0,9,22,8],
 "structztui_1_1TermLine.html#ab9630078346cb7d8426c2e77a71a62c8":[4,0,6,19,8],
 "structztui_1_1TermLine.html#ac201c617800f910c841472dacd64a759":[3,0,9,22,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX106 =
 "structztui_1_1out_1_1ListFormater.html":[3,0,9,5,1],
 "structztui_1_1out_1_1ListFormater.html":[4,0,6,3,1],
 "structztui_1_1out_1_1ListFormater.html#a02f0cbe18ba27fd1f60fb0abcad68c3a":[3,0,9,5,1,0],
-"structztui_1_1out_1_1ListFormater.html#a02f0cbe18ba27fd1f60fb0abcad68c3a":[4,0,6,3,1,0],
-"structztui_1_1out_1_1ListFormater.html#aafd2e56cf36ff9607da798700f13aa93":[3,0,9,5,1,1],
-"structztui_1_1out_1_1ListFormater.html#aafd2e56cf36ff9607da798700f13aa93":[4,0,6,3,1,1]
+"structztui_1_1out_1_1ListFormater.html#a02f0cbe18ba27fd1f60fb0abcad68c3a":[4,0,6,3,1,0]
 };
