@@ -1,5 +1,7 @@
 var NAVTREEINDEX112 =
 {
+"structzypp_1_1PoolQueryAttr.html#abf7a9879c5760780ca5d129cefb7ab45":[4,0,7,175,15],
+"structzypp_1_1PoolQueryAttr.html#afe531492b0484fe4c46b46d0caf9d6dc":[3,0,10,184,10],
 "structzypp_1_1PoolQueryAttr.html#afe531492b0484fe4c46b46d0caf9d6dc":[4,0,7,175,10],
 "structzypp_1_1ProblemSolution_1_1Impl.html":[3,0,10,186,0],
 "structzypp_1_1ProblemSolution_1_1Impl.html":[4,0,7,177,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX112 =
 "structzypp_1_1RW__pointer.html#a551d27f5c370bfebddaaff489b5cfc2c":[3,0,10,216,29],
 "structzypp_1_1RW__pointer.html#a551d27f5c370bfebddaaff489b5cfc2c":[4,0,7,207,29],
 "structzypp_1_1RW__pointer.html#a5df85c4ada8d26201b4c767b98ff4f9e":[3,0,10,216,42],
-"structzypp_1_1RW__pointer.html#a5df85c4ada8d26201b4c767b98ff4f9e":[4,0,7,207,42],
-"structzypp_1_1RW__pointer.html#a5f9e63104ae0102dd32d05f3071d286d":[3,0,10,216,26],
-"structzypp_1_1RW__pointer.html#a5f9e63104ae0102dd32d05f3071d286d":[4,0,7,207,26]
+"structzypp_1_1RW__pointer.html#a5df85c4ada8d26201b4c767b98ff4f9e":[4,0,7,207,42]
 };
