@@ -1,5 +1,7 @@
 var NAVTREEINDEX113 =
 {
+"structzypp_1_1RW__pointer.html#a5f9e63104ae0102dd32d05f3071d286d":[3,0,10,216,26],
+"structzypp_1_1RW__pointer.html#a5f9e63104ae0102dd32d05f3071d286d":[4,0,7,207,26],
 "structzypp_1_1RW__pointer.html#a5fcff6961a3ffbbc7f5d566f6374b98d":[3,0,10,216,23],
 "structzypp_1_1RW__pointer.html#a5fcff6961a3ffbbc7f5d566f6374b98d":[4,0,7,207,23],
 "structzypp_1_1RW__pointer.html#a60c788e0ea41a75c54dcd7ed5b10db90":[3,0,10,780],
@@ -247,7 +249,5 @@ var NAVTREEINDEX113 =
 "structzypp_1_1RepoInfo_1_1Impl.html#aa16fb8d54f58b1f31fa7ac62e3f03f51":[4,0,7,190,0,22],
 "structzypp_1_1RepoInfo_1_1Impl.html#aa2c1d454db323f3f8456413fd29385dd":[3,0,10,199,0,55],
 "structzypp_1_1RepoInfo_1_1Impl.html#aa2c1d454db323f3f8456413fd29385dd":[4,0,7,190,0,55],
-"structzypp_1_1RepoInfo_1_1Impl.html#aa40b470657458e40c04a80347ec496b5":[3,0,10,199,0,48],
-"structzypp_1_1RepoInfo_1_1Impl.html#aa40b470657458e40c04a80347ec496b5":[4,0,7,190,0,48],
-"structzypp_1_1RepoInfo_1_1Impl.html#aa4a134008479b68e58373647f32adc0d":[3,0,10,199,0,39]
+"structzypp_1_1RepoInfo_1_1Impl.html#aa40b470657458e40c04a80347ec496b5":[3,0,10,199,0,48]
 };
