@@ -1,5 +1,7 @@
 var NAVTREEINDEX125 =
 {
+"structzypp_1_1sat_1_1SolvableType.html#ad4bca07721482d5411a5ce68b0909216":[4,0,7,31,15,90],
+"structzypp_1_1sat_1_1SolvableType.html#ad6ef6f1dfa158710fcfc1cdf490862c0":[3,0,10,37,14,43],
 "structzypp_1_1sat_1_1SolvableType.html#ad6ef6f1dfa158710fcfc1cdf490862c0":[4,0,7,31,15,43],
 "structzypp_1_1sat_1_1SolvableType.html#adba62feeb9bf9a46011e5799cf30e857":[3,0,10,37,14,1],
 "structzypp_1_1sat_1_1SolvableType.html#adba62feeb9bf9a46011e5799cf30e857":[4,0,7,31,15,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX125 =
 "structzypp_1_1str_1_1Str.html":[3,0,10,40,4],
 "structzypp_1_1str_1_1Str.html":[4,0,7,34,4],
 "structzypp_1_1str_1_1Str.html#a0d396cda2070839d4f06303fbe204ec7":[3,0,10,40,141],
-"structzypp_1_1str_1_1Str.html#a0d396cda2070839d4f06303fbe204ec7":[3,0,10,40,4,8],
-"structzypp_1_1str_1_1Str.html#a0d396cda2070839d4f06303fbe204ec7":[4,0,7,34,4,8],
-"structzypp_1_1str_1_1Str.html#a16006b54802e5c2e57246d7887475e08":[3,0,10,40,4,2]
+"structzypp_1_1str_1_1Str.html#a0d396cda2070839d4f06303fbe204ec7":[3,0,10,40,4,8]
 };
