@@ -1,5 +1,7 @@
 var NAVTREEINDEX131 =
 {
+"structzyppng_1_1MaybeAsyncMixin.html#ad41f82ce12b1ed927c54b4235781d180":[3,0,13,107,1],
+"structzyppng_1_1MaybeAsyncMixin.html#ad41f82ce12b1ed927c54b4235781d180":[4,0,9,69,1],
 "structzyppng_1_1MaybeAsyncMixin.html#ad81f8382bfa9588dd66890b006d7c3b0":[3,0,13,107,2],
 "structzyppng_1_1MaybeAsyncMixin.html#ad81f8382bfa9588dd66890b006d7c3b0":[4,0,9,69,2],
 "structzyppng_1_1NestedAsyncOpMixin.html":[3,0,13,113],
@@ -247,7 +249,5 @@ var NAVTREEINDEX131 =
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html":[3,0,13,162,1],
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html":[4,0,9,124,1],
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html#a0c4f29a59c7a1149a5c1a3a0c0f54d98":[3,0,13,162,1,3],
-"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a0c4f29a59c7a1149a5c1a3a0c0f54d98":[4,0,9,124,1,3],
-"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a1aabdd246483d55c0249475896c95960":[3,0,13,162,1,1],
-"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a1aabdd246483d55c0249475896c95960":[4,0,9,124,1,1]
+"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a0c4f29a59c7a1149a5c1a3a0c0f54d98":[4,0,9,124,1,3]
 };
