@@ -1,5 +1,7 @@
 var NAVTREEINDEX132 =
 {
+"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a1aabdd246483d55c0249475896c95960":[3,0,13,162,1,1],
+"structzyppng_1_1SocketPrivate_1_1ClosingState.html#a1aabdd246483d55c0249475896c95960":[4,0,9,124,1,1],
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html#a878c4b6895d0c9eafb6e09478c4ea136":[3,0,13,162,1,0],
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html#a878c4b6895d0c9eafb6e09478c4ea136":[4,0,9,124,1,0],
 "structzyppng_1_1SocketPrivate_1_1ClosingState.html#aaa351467484f07c2a252da995681b6c3":[3,0,13,162,1,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX132 =
 "structzyppng_1_1detail_1_1LogicBaseExec_3_01Op_00_01std_1_1enable__if__t_3_01detail_1_1is__async__op__v_3_01Op_01_4_01_4_01_4.html":[3,0,13,15,37],
 "structzyppng_1_1detail_1_1LogicBaseExec_3_01Op_00_01std_1_1enable__if__t_3_01detail_1_1is__async__op__v_3_01Op_01_4_01_4_01_4.html":[4,0,9,1,37],
 "structzyppng_1_1detail_1_1LogicBaseExec_3_01Op_00_01std_1_1enable__if__t_3_01detail_1_1is__async__op__v_3_01Op_01_4_01_4_01_4.html#ae9928ed9c8c31654bac5c045aeeaa105":[3,0,13,15,37,0],
-"structzyppng_1_1detail_1_1LogicBaseExec_3_01Op_00_01std_1_1enable__if__t_3_01detail_1_1is__async__op__v_3_01Op_01_4_01_4_01_4.html#ae9928ed9c8c31654bac5c045aeeaa105":[4,0,9,1,37,0],
-"structzyppng_1_1detail_1_1ReadyResult.html":[3,0,13,15,49],
-"structzyppng_1_1detail_1_1ReadyResult.html":[4,0,9,1,49]
+"structzyppng_1_1detail_1_1LogicBaseExec_3_01Op_00_01std_1_1enable__if__t_3_01detail_1_1is__async__op__v_3_01Op_01_4_01_4_01_4.html#ae9928ed9c8c31654bac5c045aeeaa105":[4,0,9,1,37,0]
 };
