@@ -1,5 +1,7 @@
 var NAVTREEINDEX133 =
 {
+"structzyppng_1_1detail_1_1ReadyResult.html":[3,0,13,15,49],
+"structzyppng_1_1detail_1_1ReadyResult.html":[4,0,9,1,49],
 "structzyppng_1_1detail_1_1ReadyResult.html#a85dfd61acc0f4cdc2c1dbc78f5e90ed5":[3,0,13,15,49,0],
 "structzyppng_1_1detail_1_1ReadyResult.html#a85dfd61acc0f4cdc2c1dbc78f5e90ed5":[4,0,9,1,49,0],
 "structzyppng_1_1detail_1_1RedoWhileImpl.html":[3,0,13,15,50],
@@ -247,7 +249,5 @@ var NAVTREEINDEX133 =
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html":[3,0,13,15,35],
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html":[4,0,9,1,35],
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a052f774347beda13a0d15975144a19e6":[3,0,13,15,35,3],
-"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a052f774347beda13a0d15975144a19e6":[4,0,9,1,35,3],
-"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a415a32b26d828894230796e0e31fa0d9":[3,0,13,15,35,0],
-"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a415a32b26d828894230796e0e31fa0d9":[4,0,9,1,35,0]
+"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a052f774347beda13a0d15975144a19e6":[4,0,9,1,35,3]
 };
