@@ -1,5 +1,7 @@
 var NAVTREEINDEX134 =
 {
+"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a415a32b26d828894230796e0e31fa0d9":[3,0,13,15,35,0],
+"structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a415a32b26d828894230796e0e31fa0d9":[4,0,9,1,35,0],
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a6b8747dbf1f80462f8c5101158c5fb44":[3,0,13,15,35,7],
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#a6b8747dbf1f80462f8c5101158c5fb44":[4,0,9,1,35,7],
 "structzyppng_1_1detail_1_1lifter_3_01std_1_1shared__ptr_3_01AsyncOp_01_4_00_01std_1_1void__t_3_024104001d1cc1516b070afea75fe1753.html#ac1fde9bcdd040e6eda8c19946fa92f21":[3,0,13,15,35,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX134 =
 "structzyppng_1_1worker_1_1AuthInfo.html#a507261892df16949cba7f46bcc419c66":[3,0,13,44,2,2],
 "structzyppng_1_1worker_1_1AuthInfo.html#a507261892df16949cba7f46bcc419c66":[4,0,9,6,2,2],
 "structzyppng_1_1worker_1_1AuthInfo.html#ac3d0b95d3a3a7347150c2bb6d9e0ae98":[3,0,13,44,2,3],
-"structzyppng_1_1worker_1_1AuthInfo.html#ac3d0b95d3a3a7347150c2bb6d9e0ae98":[4,0,9,6,2,3],
-"structzyppng_1_1worker_1_1AuthInfo.html#addf4641207201d3a5914d82012ad4225":[3,0,13,44,2,1],
-"structzyppng_1_1worker_1_1AuthInfo.html#addf4641207201d3a5914d82012ad4225":[4,0,9,6,2,1]
+"structzyppng_1_1worker_1_1AuthInfo.html#ac3d0b95d3a3a7347150c2bb6d9e0ae98":[4,0,9,6,2,3]
 };
