@@ -1,5 +1,7 @@
 var NAVTREEINDEX38 =
 {
+"classzypp_1_1ZConfig.html#a52b9ddaf742452dfb8127de36c04b0cb":[2,12,0,36],
+"classzypp_1_1ZConfig.html#a5804ba6191a70e3dbed9d22105acb5fc":[2,12,0,22],
 "classzypp_1_1ZConfig.html#a5a5c16f4c73d1e8613108f7fbb5240fd":[2,12,0,8],
 "classzypp_1_1ZConfig.html#a5e96aaa65fdeddeefd6997f3ff37cf3d":[2,12,0,50],
 "classzypp_1_1ZConfig.html#a5f5be016c2c5deca5267e0e2256a0f27":[2,12,0,42],
@@ -247,7 +249,5 @@ var NAVTREEINDEX38 =
 "classzypp_1_1ZYppCommitPolicy.html#ad7e94b1f176f34c44f1771afa203cc0f":[3,0,10,244,10],
 "classzypp_1_1ZYppCommitPolicy.html#ad7e94b1f176f34c44f1771afa203cc0f":[4,0,7,235,10],
 "classzypp_1_1ZYppCommitPolicy.html#ae73b3d53492778d51f60f2859f430f3f":[3,0,10,244,18],
-"classzypp_1_1ZYppCommitPolicy.html#ae73b3d53492778d51f60f2859f430f3f":[4,0,7,235,18],
-"classzypp_1_1ZYppCommitPolicy_1_1Impl.html":[3,0,10,244,0],
-"classzypp_1_1ZYppCommitPolicy_1_1Impl.html":[4,0,7,235,0]
+"classzypp_1_1ZYppCommitPolicy.html#ae73b3d53492778d51f60f2859f430f3f":[4,0,7,235,18]
 };
