@@ -1,5 +1,7 @@
 var NAVTREEINDEX39 =
 {
+"classzypp_1_1ZYppCommitPolicy_1_1Impl.html":[3,0,10,244,0],
+"classzypp_1_1ZYppCommitPolicy_1_1Impl.html":[4,0,7,235,0],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a46365af2af9f2ed1ab71a4b057c1e800":[3,0,10,244,0,1],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a46365af2af9f2ed1ab71a4b057c1e800":[4,0,7,235,0,1],
 "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[3,0,10,244,0,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX39 =
 "classzypp_1_1__logtoolsdetail_1_1MapEntry.html#a601df053500c36942ee92391baaeb273":[4,0,7,0,3,3],
 "classzypp_1_1__logtoolsdetail_1_1MapEntry.html#afcc5283b99157f9bd7ebcc7c3f19c7d8":[3,0,10,0,3,4],
 "classzypp_1_1__logtoolsdetail_1_1MapEntry.html#afcc5283b99157f9bd7ebcc7c3f19c7d8":[4,0,7,0,3,4],
-"classzypp_1_1base_1_1Flags.html":[3,0,10,2,3],
-"classzypp_1_1base_1_1Flags.html":[4,0,7,1,2],
-"classzypp_1_1base_1_1Flags.html#a016d1a88525b85e27413c9973129423e":[3,0,10,2,3,21]
+"classzypp_1_1base_1_1Flags.html":[3,0,10,2,3]
 };
