@@ -1,5 +1,7 @@
 var NAVTREEINDEX41 =
 {
+"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ae6ae9ebadd086e9e149e36d323173d3b":[4,0,7,1,0,1,14],
+"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#af82367a7ff7ceb46f6cd982f430652f4":[3,0,10,2,0,1,5],
 "classzypp_1_1base_1_1logger_1_1Loglinebuf.html#af82367a7ff7ceb46f6cd982f430652f4":[4,0,7,1,0,1,5],
 "classzypp_1_1base_1_1logger_1_1Loglinestream.html":[3,0,10,2,0,2],
 "classzypp_1_1base_1_1logger_1_1Loglinestream.html":[4,0,7,1,0,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX41 =
 "classzypp_1_1detail_1_1FdStreamBufImpl.html#a4fabea0f1bca6dcb653becd0aeccfe82":[3,0,10,6,3,7],
 "classzypp_1_1detail_1_1FdStreamBufImpl.html#a4fabea0f1bca6dcb653becd0aeccfe82":[4,0,7,5,3,7],
 "classzypp_1_1detail_1_1FdStreamBufImpl.html#a5cf61b1a3480f7498679691d2d3eb029":[3,0,10,6,3,0],
-"classzypp_1_1detail_1_1FdStreamBufImpl.html#a5cf61b1a3480f7498679691d2d3eb029":[4,0,7,5,3,0],
-"classzypp_1_1detail_1_1FdStreamBufImpl.html#a5d62c82077ef4e9f76a77a5aeda14f16":[3,0,10,6,3,13],
-"classzypp_1_1detail_1_1FdStreamBufImpl.html#a5d62c82077ef4e9f76a77a5aeda14f16":[4,0,7,5,3,13]
+"classzypp_1_1detail_1_1FdStreamBufImpl.html#a5cf61b1a3480f7498679691d2d3eb029":[4,0,7,5,3,0]
 };
