@@ -1,5 +1,7 @@
 var NAVTREEINDEX53 =
 {
+"classzypp_1_1media_1_1MediaUnmountException.html#aebf39516fe101187e2f84ecaef07a602":[3,0,10,25,62,3],
+"classzypp_1_1media_1_1MediaUnmountException.html#aebf39516fe101187e2f84ecaef07a602":[4,0,7,22,62,3],
 "classzypp_1_1media_1_1MediaUnsupportedUrlSchemeException.html":[3,0,10,25,63],
 "classzypp_1_1media_1_1MediaUnsupportedUrlSchemeException.html":[4,0,7,22,63],
 "classzypp_1_1media_1_1MediaUnsupportedUrlSchemeException.html#a590e646b550326ad59d21db88b7bb7d8":[3,0,10,25,63,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX53 =
 "classzypp_1_1media_1_1TransferSettings.html#aa27c1713c1449370f32007b5a071c366":[3,0,10,25,77,28],
 "classzypp_1_1media_1_1TransferSettings.html#aa27c1713c1449370f32007b5a071c366":[4,0,7,22,77,28],
 "classzypp_1_1media_1_1TransferSettings.html#aa3a8ea69011f292fa709a3ac88c8804f":[3,0,10,25,77,44],
-"classzypp_1_1media_1_1TransferSettings.html#aa3a8ea69011f292fa709a3ac88c8804f":[4,0,7,22,77,44],
-"classzypp_1_1media_1_1TransferSettings.html#aa86f7fba1f17dbff5532a2b04dde52b6":[3,0,10,25,77,61],
-"classzypp_1_1media_1_1TransferSettings.html#aa86f7fba1f17dbff5532a2b04dde52b6":[4,0,7,22,77,61]
+"classzypp_1_1media_1_1TransferSettings.html#aa3a8ea69011f292fa709a3ac88c8804f":[4,0,7,22,77,44]
 };
