@@ -1,5 +1,7 @@
 var NAVTREEINDEX54 =
 {
+"classzypp_1_1media_1_1TransferSettings.html#aa86f7fba1f17dbff5532a2b04dde52b6":[3,0,10,25,77,61],
+"classzypp_1_1media_1_1TransferSettings.html#aa86f7fba1f17dbff5532a2b04dde52b6":[4,0,7,22,77,61],
 "classzypp_1_1media_1_1TransferSettings.html#ab3cdd1c40dd589b61dd0475d89241644":[3,0,10,25,77,19],
 "classzypp_1_1media_1_1TransferSettings.html#ab3cdd1c40dd589b61dd0475d89241644":[4,0,7,22,77,19],
 "classzypp_1_1media_1_1TransferSettings.html#ab47bff3574fdc55bd83209201675769f":[3,0,10,25,77,38],
@@ -247,7 +249,5 @@ var NAVTREEINDEX54 =
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a52394d093b5635b7a140ffd43de2b31c":[4,0,7,23,0,5,30],
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a5756d4b34e1ac2eb8e91503c25cce81b":[3,0,10,26,0,5,8],
 "classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a5756d4b34e1ac2eb8e91503c25cce81b":[4,0,7,23,0,5,8],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a5cf9ab23c0b4c8003be3c9a72885cf88":[3,0,10,26,0,5,31],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a5cf9ab23c0b4c8003be3c9a72885cf88":[4,0,7,23,0,5,31],
-"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a830907cb0ec8bfb08bb0758692bb8101":[3,0,10,26,0,5,15]
+"classzypp_1_1misc_1_1testcase_1_1TestcaseSetup.html#a5cf9ab23c0b4c8003be3c9a72885cf88":[3,0,10,26,0,5,31]
 };
