@@ -1,5 +1,7 @@
 var NAVTREEINDEX59 =
 {
+"classzypp_1_1repo_1_1RpmSigCheckException.html#af742eb2b3689c7900432d3d479058c61":[3,0,10,32,29,1],
+"classzypp_1_1repo_1_1RpmSigCheckException.html#af742eb2b3689c7900432d3d479058c61":[4,0,7,27,28,1],
 "classzypp_1_1repo_1_1SUSEMediaVerifier.html":[3,0,10,32,41],
 "classzypp_1_1repo_1_1SUSEMediaVerifier.html":[4,0,7,27,40],
 "classzypp_1_1repo_1_1SUSEMediaVerifier.html#a07cd953960a3eb365f075768e78c9773":[3,0,10,32,41,7],
@@ -247,7 +249,5 @@ var NAVTREEINDEX59 =
 "classzypp_1_1sat_1_1LocaleSupport.html#aaff7c43d9824a6d3cf3fb660243bda70":[4,0,7,31,7,0],
 "classzypp_1_1sat_1_1LocaleSupport.html#ab577770cc06e7433347e5bad9ca0bd89":[3,0,10,37,6,2],
 "classzypp_1_1sat_1_1LocaleSupport.html#ab577770cc06e7433347e5bad9ca0bd89":[4,0,7,31,7,2],
-"classzypp_1_1sat_1_1LocaleSupport.html#aca92413248f3f38aed088726cb744fab":[3,0,10,37,6,4],
-"classzypp_1_1sat_1_1LocaleSupport.html#aca92413248f3f38aed088726cb744fab":[4,0,7,31,7,4],
-"classzypp_1_1sat_1_1LocaleSupport.html#acaa6ce053cc9192e4a90bdea709e8018":[3,0,10,37,6,7]
+"classzypp_1_1sat_1_1LocaleSupport.html#aca92413248f3f38aed088726cb744fab":[3,0,10,37,6,4]
 };
