@@ -1,5 +1,7 @@
 var NAVTREEINDEX63 =
 {
+"classzypp_1_1sat_1_1SolvAttr.html#ada31f7d7b3ce3bd74c7875a1592ab92a":[4,0,7,31,16,48],
+"classzypp_1_1sat_1_1SolvAttr.html#add4b67f1d14062273aa7234c1fbde91d":[3,0,10,37,15,8],
 "classzypp_1_1sat_1_1SolvAttr.html#add4b67f1d14062273aa7234c1fbde91d":[4,0,7,31,16,8],
 "classzypp_1_1sat_1_1SolvAttr.html#adf3231abe74e7f5a8db071178c115a90":[3,0,10,37,15,84],
 "classzypp_1_1sat_1_1SolvAttr.html#adf3231abe74e7f5a8db071178c115a90":[4,0,7,31,16,84],
@@ -247,7 +249,5 @@ var NAVTREEINDEX63 =
 "classzypp_1_1sat_1_1Solvable.html#aa3338f402986e5b79aa35e95394952fc":[4,0,7,31,13,71],
 "classzypp_1_1sat_1_1Solvable.html#aab872c7999cadef0e796dc2fe248a287":[3,0,10,37,12,46],
 "classzypp_1_1sat_1_1Solvable.html#aab872c7999cadef0e796dc2fe248a287":[4,0,7,31,13,46],
-"classzypp_1_1sat_1_1Solvable.html#aafabaa82597ed19c857910b3623f44f2":[3,0,10,37,12,38],
-"classzypp_1_1sat_1_1Solvable.html#aafabaa82597ed19c857910b3623f44f2":[4,0,7,31,13,38],
-"classzypp_1_1sat_1_1Solvable.html#ab49a760ae985edd66ad1a9560309766f":[3,0,10,37,12,82]
+"classzypp_1_1sat_1_1Solvable.html#aafabaa82597ed19c857910b3623f44f2":[3,0,10,37,12,38]
 };
