@@ -1,5 +1,7 @@
 var NAVTREEINDEX64 =
 {
+"classzypp_1_1sat_1_1Solvable.html#aafabaa82597ed19c857910b3623f44f2":[4,0,7,31,13,38],
+"classzypp_1_1sat_1_1Solvable.html#ab49a760ae985edd66ad1a9560309766f":[3,0,10,37,12,82],
 "classzypp_1_1sat_1_1Solvable.html#ab49a760ae985edd66ad1a9560309766f":[4,0,7,31,13,82],
 "classzypp_1_1sat_1_1Solvable.html#ab8662c2ef2562a9964a7245f44e8e52c":[3,0,10,37,12,59],
 "classzypp_1_1sat_1_1Solvable.html#ab8662c2ef2562a9964a7245f44e8e52c":[4,0,7,31,13,59],
@@ -247,7 +249,5 @@ var NAVTREEINDEX64 =
 "classzypp_1_1sat_1_1Transaction.html#afc02b4436bf473d33764edd15a0882d6":[4,0,7,31,18,26],
 "classzypp_1_1sat_1_1Transaction_1_1Step.html":[3,0,10,37,17,3],
 "classzypp_1_1sat_1_1Transaction_1_1Step.html":[4,0,7,31,18,3],
-"classzypp_1_1sat_1_1Transaction_1_1Step.html#a0e6b21e974655c170944bd87c5571185":[3,0,10,37,17,3,9],
-"classzypp_1_1sat_1_1Transaction_1_1Step.html#a0e6b21e974655c170944bd87c5571185":[4,0,7,31,18,3,9],
-"classzypp_1_1sat_1_1Transaction_1_1Step.html#a1592a00943f098adedbaebcd19f9bb07":[3,0,10,37,17,3,8]
+"classzypp_1_1sat_1_1Transaction_1_1Step.html#a0e6b21e974655c170944bd87c5571185":[3,0,10,37,17,3,9]
 };
