@@ -1,5 +1,7 @@
 var NAVTREEINDEX66 =
 {
+"classzypp_1_1sat_1_1detail_1_1PoolImpl.html#ab2d4ac549d2a2e1e4f92d16fee14a5f6":[3,0,10,37,0,1,65],
+"classzypp_1_1sat_1_1detail_1_1PoolImpl.html#ab2d4ac549d2a2e1e4f92d16fee14a5f6":[4,0,7,31,0,1,65],
 "classzypp_1_1sat_1_1detail_1_1PoolImpl.html#ab8519cb16fd30497d4bced9912f6b919":[3,0,10,37,0,1,62],
 "classzypp_1_1sat_1_1detail_1_1PoolImpl.html#ab8519cb16fd30497d4bced9912f6b919":[4,0,7,31,0,1,62],
 "classzypp_1_1sat_1_1detail_1_1PoolImpl.html#ab9a96328d8283f2ff2641147d010458a":[3,0,10,37,0,1,23],
@@ -247,7 +249,5 @@ var NAVTREEINDEX66 =
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a2b50ed14770c06409eb825141ec8af41":[3,0,10,39,0,8,7],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a2b50ed14770c06409eb825141ec8af41":[4,0,7,33,0,8,7],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a403b2586c97d8bb32c119bd8ebd288cb":[3,0,10,39,0,8,10],
-"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a403b2586c97d8bb32c119bd8ebd288cb":[4,0,7,33,0,8,10],
-"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a4f2ea1a1ed3489a669aa78f9d0136106":[3,0,10,39,0,8,0],
-"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a4f2ea1a1ed3489a669aa78f9d0136106":[4,0,7,33,0,8,0]
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a403b2586c97d8bb32c119bd8ebd288cb":[4,0,7,33,0,8,10]
 };
