@@ -1,5 +1,7 @@
 var NAVTREEINDEX71 =
 {
+"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html":[4,0,7,36,0,20],
+"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html#a2117399fd1de4eb303d4b0022153c69b":[3,0,10,43,0,21,4],
 "classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html#a2117399fd1de4eb303d4b0022153c69b":[4,0,7,36,0,20,4],
 "classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html#a3c4fdd0f8e70b5ff3ef67df57d62fc14":[3,0,10,43,0,21,2],
 "classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html#a3c4fdd0f8e70b5ff3ef67df57d62fc14":[4,0,7,36,0,20,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX71 =
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a11143bda3c34c6d6050e61a3e03bd005":[4,0,7,36,0,11,0,8],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a1633934326314f3c0b5cefeeecc73ee3":[3,0,10,43,0,12,0,6],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a1633934326314f3c0b5cefeeecc73ee3":[4,0,7,36,0,11,0,6],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a25baa3b6f09fc50522035796bcf6fb97":[3,0,10,43,0,12,0,1],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a25baa3b6f09fc50522035796bcf6fb97":[4,0,7,36,0,11,0,1],
-"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a2eb9c8883ba716f92fa42fd9698a62b7":[3,0,10,43,0,12,0,2]
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1D.html#a25baa3b6f09fc50522035796bcf6fb97":[3,0,10,43,0,12,0,1]
 };
