@@ -1,5 +1,7 @@
 var NAVTREEINDEX81 =
 {
+"classzyppng_1_1IODevice.html#ade05f3e0943d1d149259e91152320f61":[3,0,13,97,4],
+"classzyppng_1_1IODevice.html#ade05f3e0943d1d149259e91152320f61":[4,0,9,59,4],
 "classzyppng_1_1IODevice.html#ae13cd302ee517f3cc9c90fdd9cdc8ced":[3,0,13,97,3],
 "classzyppng_1_1IODevice.html#ae13cd302ee517f3cc9c90fdd9cdc8ced":[4,0,9,59,3],
 "classzyppng_1_1IODevice.html#ae55cab5a8355eb0884b648f66ce904cb":[3,0,13,97,31],
@@ -247,7 +249,5 @@ var NAVTREEINDEX81 =
 "classzyppng_1_1MediaSyncFacade_1_1Res.html#a3738ad7217c583aa1afeb14c6733e582":[3,0,13,109,0,2],
 "classzyppng_1_1MediaSyncFacade_1_1Res.html#a3738ad7217c583aa1afeb14c6733e582":[4,0,9,71,0,2],
 "classzyppng_1_1MediaSyncFacade_1_1Res.html#a541498085b9622e30e6f832f90643dcb":[3,0,13,109,0,0],
-"classzyppng_1_1MediaSyncFacade_1_1Res.html#a541498085b9622e30e6f832f90643dcb":[4,0,9,71,0,0],
-"classzyppng_1_1MediaSyncFacade_1_1Res.html#adc98fb1fc7d0e911807d9a5efbcf0a2b":[3,0,13,109,0,3],
-"classzyppng_1_1MediaSyncFacade_1_1Res.html#adc98fb1fc7d0e911807d9a5efbcf0a2b":[4,0,9,71,0,3]
+"classzyppng_1_1MediaSyncFacade_1_1Res.html#a541498085b9622e30e6f832f90643dcb":[4,0,9,71,0,0]
 };
