@@ -1,5 +1,7 @@
 var NAVTREEINDEX84 =
 {
+"classzyppng_1_1ProgressObserver.html":[3,0,13,123],
+"classzyppng_1_1ProgressObserver.html":[4,0,9,85],
 "classzyppng_1_1ProgressObserver.html#a0354b22b99eb7b34c0f416b3bb779afc":[3,0,13,123,30],
 "classzyppng_1_1ProgressObserver.html#a0354b22b99eb7b34c0f416b3bb779afc":[4,0,9,85,30],
 "classzyppng_1_1ProgressObserver.html#a1588c89f2fa79a575dfd9d298233d17e":[3,0,13,123,27],
@@ -247,7 +249,5 @@ var NAVTREEINDEX84 =
 "classzyppng_1_1ProvideFileItem.html#aecf6e08920807725f21318c58c0d71a4":[3,0,13,127,20],
 "classzyppng_1_1ProvideFileItem.html#aecf6e08920807725f21318c58c0d71a4":[4,0,9,89,20],
 "classzyppng_1_1ProvideFileSpec.html":[3,0,13,128],
-"classzyppng_1_1ProvideFileSpec.html":[4,0,9,90],
-"classzyppng_1_1ProvideFileSpec.html#a1547cef58c8c282a032022d5e33514ae":[3,0,13,128,1],
-"classzyppng_1_1ProvideFileSpec.html#a1547cef58c8c282a032022d5e33514ae":[4,0,9,90,1]
+"classzyppng_1_1ProvideFileSpec.html":[4,0,9,90]
 };
