@@ -1,5 +1,7 @@
 var NAVTREEINDEX90 =
 {
+"classzyppng_1_1StompFrameStream.html#aa64b7c890b881269e531b76bcb6f8aa6":[3,0,13,164,14],
+"classzyppng_1_1StompFrameStream.html#aa64b7c890b881269e531b76bcb6f8aa6":[4,0,9,126,14],
 "classzyppng_1_1StompFrameStream.html#aacc7478056bad0d8602d7b142651c464":[3,0,13,164,21],
 "classzyppng_1_1StompFrameStream.html#aacc7478056bad0d8602d7b142651c464":[4,0,9,126,21],
 "classzyppng_1_1StompFrameStream.html#ac760e9b14edac93a6a3042ed65de95a3":[3,0,13,164,18],
@@ -247,7 +249,5 @@ var NAVTREEINDEX90 =
 "classzyppng_1_1UserRequest.html#abe078b4d0c30a9916848d6f7f3f72be3":[3,0,13,179,4],
 "classzyppng_1_1UserRequest.html#abe078b4d0c30a9916848d6f7f3f72be3":[4,0,9,141,4],
 "classzyppng_1_1UserRequest.html#ae8a3a69fc34e930e03bb3c315b4a99df":[3,0,13,179,1],
-"classzyppng_1_1UserRequest.html#ae8a3a69fc34e930e03bb3c315b4a99df":[4,0,9,141,1],
-"classzyppng_1_1UserRequest.html#aeddbab93cb949c513aece09d9e32299a":[3,0,13,179,2],
-"classzyppng_1_1UserRequest.html#aeddbab93cb949c513aece09d9e32299a":[4,0,9,141,2]
+"classzyppng_1_1UserRequest.html#ae8a3a69fc34e930e03bb3c315b4a99df":[4,0,9,141,1]
 };
