@@ -1,5 +1,7 @@
 var NAVTREEINDEX96 =
 {
+"namespaceztui.html#a0b22ccecde71aac87fb0df895222c2db":[3,0,9,83],
+"namespaceztui.html#a0d32dedf250989f15cb2c3715893ff77":[3,0,9,32],
 "namespaceztui.html#a0ffcdc0cf4266ea29d364aa876351cd0":[3,0,9,73],
 "namespaceztui.html#a1109aff1e3b37493945349a444f6f16b":[3,0,9,42],
 "namespaceztui.html#a12a93a7b8d0552881f516d6409aba428":[3,0,9,30],
@@ -247,7 +249,5 @@ var NAVTREEINDEX96 =
 "namespacezypp.html#a29b253ac822197b39a19e7107a946d59":[3,0,10,422],
 "namespacezypp.html#a2a75e7a270fb8b4328d044094f0ebe2b":[3,0,10,619],
 "namespacezypp.html#a2aa63453578dc725c2d63502a23e427e":[3,0,10,535],
-"namespacezypp.html#a2c01c08128d0ca2003b29fc2ef59fb90":[3,0,10,575],
-"namespacezypp.html#a2c2f94c5edfe13852c002fdb329a6e71":[3,0,10,592],
-"namespacezypp.html#a2e8fe5e48769b7edd28aa142883beb34":[3,0,10,608]
+"namespacezypp.html#a2c01c08128d0ca2003b29fc2ef59fb90":[3,0,10,575]
 };
